@@ -62,8 +62,6 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 		onstat(k) = static_cast<double>(Second(i_k));
 	}
 
-
-
 	/***********************
 	Parameter Initialization
 	***********************/
@@ -71,15 +69,15 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 	mat gamR = gamR_init;
 	mat Omega = Omega_init;
 	mat Omegainv = Omega.i();
-	mat Sig_lt(N, (J*(J+1))/2, fill::zeros); // store the diagonal-incluseive lower triangular (lt) elements of Sig
-	mat Siginv_lt(N, (J*(J+1))/2, fill::zeros); // store the diagonal-incluseive lower triangular (lt) elements of Siginv
+	mat Sig_lt(N, (J*(J+1))/2, fill::zeros); // store the diagonal-inclusive lower triangular (lt) elements of Sig
+	mat Siginv_lt(N, (J*(J+1))/2, fill::zeros); // store the diagonal-inclusive lower triangular (lt) elements of Siginv
 	mat vRtk(N, J * (J - 1) / 2, fill::zeros); // store the off-diagonal lower triangular elements of normal variates for Rtk
 	vRtk.fill(0.5);
 	mat delta = SD;
 	mat Rho = Rho_init;
 	mat pRho = Rho_to_pRho(Rho);
 	mat Rhoinv = arma::inv(Rho);
-	vec vRho = arma::atanh(vecr(Rho));
+	vec vRho = arma::atanh(vecr(pRho));
 
 	for (int i = 0; i < N; ++i) {
 		mat Sigma = arma::diagmat(delta.row(i)) * Rho * arma::diagmat(delta.row(i));
@@ -173,8 +171,7 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 			}
 			Sig_theta = 0.5 * (Sig_theta + Sig_theta.t());
 			mat Sig_theta_chol = arma::chol(Sig_theta);
-			vec ttmp(nt);
-			std::generate(ttmp.begin(), ttmp.end(), ::norm_rand);
+			vec ttmp(nt, fill::randn);
 			theta = arma::solve(arma::trimatu(Sig_theta_chol), arma::solve(arma::trimatl(Sig_theta_chol.t()), mu_theta) + ttmp);
 
 			for (int i = 0; i < N; ++i) {
@@ -225,8 +222,7 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 				}
 				Siggam = 0.5 * (Siggam + Siggam.t());
 				mat SiggamChol = arma::chol(Siggam);
-				vec gtmp(nw*J);
-				std::generate(gtmp.begin(), gtmp.end(), ::norm_rand);
+				vec gtmp(nw*J, fill::randn);
 				gamR.col(k) = arma::solve(arma::trimatu(SiggamChol), arma::solve(arma::trimatl(SiggamChol.t()), mugam) + gtmp);
 				for (int j = 0; j < J; ++j) {
 					for (int j2 = 0; j2 < nn; ++j2) {
@@ -363,8 +359,7 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 					mat siginvm = arma::diagmat(1.0 / delta.row(i));
 					qq += siginvm * dAd * siginvm;
 				}
-				vec U(J*(J-1)/2);
-				std::generate(U.begin(), U.end(), ::norm_rand);
+				vec U(J*(J-1)/2, fill::randn);
 				vec vRhop = vRho + SS * U;
 
 				vec z = arma::tanh(vRhop);
@@ -389,7 +384,7 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 						++vRho_rates;
 					} else {
 						// delayed rejection
-						std::generate(U.begin(), U.end(), ::norm_rand);
+						U.randn();
 						vec zzz = vRho + std::sqrt(0.5) * (SS * U);
 
 						mat pRRhozzz = vecrinv(arma::tanh(zzz), J);
@@ -567,8 +562,7 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 				}
 				Sig_theta = 0.5 * (Sig_theta + Sig_theta.t());
 				mat Sig_theta_chol = arma::chol(Sig_theta);
-				vec ttmp(nt);
-				std::generate(ttmp.begin(), ttmp.end(), ::norm_rand);
+				vec ttmp(nt, fill::randn);
 				theta = arma::solve(arma::trimatu(Sig_theta_chol), arma::solve(arma::trimatl(Sig_theta_chol.t()), mu_theta) + ttmp);
 
 				for (int i = 0; i < N; ++i) {
@@ -619,8 +613,7 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 					}
 					Siggam = 0.5 * (Siggam + Siggam.t());
 					mat SiggamChol = arma::chol(Siggam);
-					vec gtmp(nw*J);
-					std::generate(gtmp.begin(), gtmp.end(), ::norm_rand);
+					vec gtmp(nw*J, fill::randn);
 					gamR.col(k) = arma::solve(arma::trimatu(SiggamChol), arma::solve(arma::trimatl(SiggamChol.t()), mugam) + gtmp);
 					for (int j = 0; j < J; ++j) {
 						for (int j2 = 0; j2 < nn; ++j2) {
@@ -758,8 +751,7 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 						mat siginvm = arma::diagmat(1.0 / delta.row(i));
 						qq += siginvm * dAd * siginvm;
 					}
-					vec U(J*(J-1)/2);
-					std::generate(U.begin(), U.end(), ::norm_rand);
+					vec U(J*(J-1)/2, fill::randn);
 					vec vRhop = vRho + SS * U;
 
 					vec z = arma::tanh(vRhop);
@@ -784,7 +776,7 @@ Rcpp::List fmodel3pp(const arma::mat& Outcome,
 							++vRho_rates;
 						} else {
 							// delayed rejection
-							std::generate(U.begin(), U.end(), ::norm_rand);
+							U.randn();
 							vec zzz = vRho + std::sqrt(0.5) * (SS * U);
 
 							mat pRRhozzz = vecrinv(arma::tanh(zzz), J);
